@@ -20,7 +20,13 @@ import typing as t
 from elastic_transport import ObjectApiResponse
 
 from ._base import NamespacedClient
-from .utils import SKIP_IN_PATH, _quote, _rewrite_parameters
+from .utils import (
+    SKIP_IN_PATH,
+    Stability,
+    _quote,
+    _rewrite_parameters,
+    _stability_warning,
+)
 
 
 class FleetClient(NamespacedClient):
@@ -43,7 +49,7 @@ class FleetClient(NamespacedClient):
         Returns the current global checkpoints for an index. This API is design for internal
         use by the fleet server project.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/get-global-checkpoints.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/get-global-checkpoints.html>`_
 
         :param index: A single index or index alias that resolves to a single index.
         :param checkpoints: A comma separated list of previous global checkpoints. When
@@ -91,6 +97,7 @@ class FleetClient(NamespacedClient):
     @_rewrite_parameters(
         body_name="searches",
     )
+    @_stability_warning(Stability.EXPERIMENTAL)
     async def msearch(
         self,
         *,
@@ -277,6 +284,7 @@ class FleetClient(NamespacedClient):
             "from": "from_",
         },
     )
+    @_stability_warning(Stability.EXPERIMENTAL)
     async def search(
         self,
         *,
